Vasuki.FileSystem.DirWalk (Vasuki v0.1.2) View Source
DirWalk accept new path to traverse via ls returning first path, and every next file entry via next.
It maintains state through crash using Vasuki.Data.Mucket.
Link to this section Summary
Functions
Returns a specification to start this module under a supervisor.
Callback implementation for GenServer.init/1.
ls adds provided dirpath to list to be traversed and returns top file in queue to returned
next returns one file at a time for directories queued up to traversed recrusively using 'ls'
reset simple cleans up the state
Link to this section Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
Callback implementation for GenServer.init/1.
ls adds provided dirpath to list to be traversed and returns top file in queue to returned
next returns one file at a time for directories queued up to traversed recrusively using 'ls'
reset simple cleans up the state